#!/usr/bin/env python

from setuptools import setup

setup(name='ssx',
      version='0.0.1',
      description='Synchrotron serial crystallography tools',
      author='Jerome Kieffer',
      author_email='jerome.kieffer@esrf.fr',
      url='https://github.com/kif/ssx',
      packages=['ssx'],
     )
